@@ -1,9 +1,6 @@
 from smartrent.api import async_login
 from smartrent.lock import DoorLock
 from smartrent.thermostat import Thermostat
+from smartrent.utils import Client
 
-__all__ = [
-    "async_login",
-    "DoorLock",
-    "Thermostat"
-]
+__all__ = ["async_login", "DoorLock", "Thermostat", "Client"]
